summaryrefslogtreecommitdiffstats
path: root/llvm
diff options
context:
space:
mode:
authorDuncan Sands <baldrick@free.fr>2008-08-13 08:56:48 +0000
committerDuncan Sands <baldrick@free.fr>2008-08-13 08:56:48 +0000
commita21ff583db91420cc2e9c793b217677a83b3d383 (patch)
tree424d6d08283fdcf3a07585c7583aabcb0430b7b9 /llvm
parent92c64ae2d04126ad84f71cd749324db2b3e6a2cd (diff)
downloadbcm5719-llvm-a21ff583db91420cc2e9c793b217677a83b3d383.tar.gz
bcm5719-llvm-a21ff583db91420cc2e9c793b217677a83b3d383.zip
Rename this, in case people think that NullFolder
has something to do with folding null values. llvm-svn: 54725
Diffstat (limited to 'llvm')
-rw-r--r--llvm/include/llvm/Support/NoFolder.h (renamed from llvm/include/llvm/Support/NullFolder.h)8
1 files changed, 4 insertions, 4 deletions
diff --git a/llvm/include/llvm/Support/NullFolder.h b/llvm/include/llvm/Support/NoFolder.h
index 634d38eb6a0..f4bec629617 100644
--- a/llvm/include/llvm/Support/NullFolder.h
+++ b/llvm/include/llvm/Support/NoFolder.h
@@ -1,4 +1,4 @@
//=====-- llvm/Support/NullFolder.h - Constant folding helper -*- C++ -*-=====//
//
// The LLVM Compiler Infrastructure
//
@@ -7,7 +7,7 @@
//
//===----------------------------------------------------------------------===//
//
// This file defines the NullFolder class, a helper for IRBuilder. It provides
// IRBuilder with a set of methods for creating unfolded constants. This is
// useful for learners trying to understand how LLVM IR works, and who don't
// want details to be hidden by the constant folder. For general constant
@@ -28,8 +28,8 @@
namespace llvm {
-/// NullFolder - Create "constants" (actually, values) with no folding.
-class NullFolder {
+/// NoFolder - Create "constants" (actually, values) with no folding.
+class NoFolder {
public:
//===--------------------------------------------------------------------===//
OpenPOWER on IntegriCloud
@@ -1,4 +1,4 @@
-//=====-- llvm/Support/NullFolder.h - Constant folding helper -*- C++ -*-=====//
+//======-- llvm/Support/NoFolder.h - Constant folding helper -*- C++ -*-======//
//
// The LLVM Compiler Infrastructure
@@ -7,7 +7,7 @@
//===----------------------------------------------------------------------===//
//
-// This file defines the NullFolder class, a helper for IRBuilder. It provides
+// This file defines the NoFolder class, a helper for IRBuilder. It provides
// IRBuilder with a set of methods for creating unfolded constants. This is
// useful for learners trying to understand how LLVM IR works, and who don't